﻿import { Injectable, Inject, Optional } from '@angular/core';

import * as tinymce from 'tinymce';

import { MaterialsWidthHelper } from 'ivy.angular.material.helpers';
import { TinyEditorInlineConfiguration } from '../Models/tiny-editor-inline-configuration.model';

@Injectable()
export class TinyMceConfigurationService {

    constructor(
        @Optional() @Inject('TinyEditorInlineConfiguration') private config: TinyEditorInlineConfiguration,
        private matWidthHelper: MaterialsWidthHelper) {
    }


    generateConfigs(elementId: string, setupFn: (editor: tinymce.Editor) => void): tinymce.Settings {

        let tinyMceConfig: tinymce.Settings = {
            selector: '#' + elementId,
            inline: true,
            insert_toolbar: '',
            setup: setupFn,
            theme: 'modern'
        };

        if (this.matWidthHelper.isXs()) {
            tinyMceConfig.theme = 'inlite';
        }

        if (this.config) {
            tinyMceConfig.content_css = this.config.cssLocation;
            tinyMceConfig.plugins = this.config.plugins;
            tinyMceConfig.menubar = this.config.menubar;
            tinyMceConfig.toolbar = this.config.toolbar;
        }

        return tinyMceConfig;
    }
}